pydse package
=============

Subpackages
-----------

.. toctree::

    pydse.data

Submodules
----------

pydse.arma module
-----------------

.. automodule:: pydse.arma
    :members:
    :undoc-members:
    :show-inheritance:

pydse.stats module
------------------

.. automodule:: pydse.stats
    :members:
    :undoc-members:
    :show-inheritance:

pydse.utils module
------------------

.. automodule:: pydse.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pydse
    :members:
    :undoc-members:
    :show-inheritance:
